@@ -4,6 +4,13 @@ from functional.streams import Sequence
 from lxml import etree
 
 
+def safe_xpath(n, xpath, default=None):
+    try:
+        return n.xpath(xpath)[0].text
+    except RuntimeError:
+        return default
+
+
 def no_whitespace():
     return str.maketrans({chr(13): '', chr(10): '', chr(9): ''})
 
@@ -226,6 +233,6 @@ class Connection(object):
                     "short": str(n.xpath("td[4]/following::text()[4]")[0]).translate(no_whitespace()),
                 },
                 "comment": trim_whitespace(n.xpath("td[6]/textarea")[0].text),
-                "duration": (float(n.xpath("td[8]/select[1]/option[@selected]")[0].text) * 60.0 +
-                             float(n.xpath("td[8]/select[2]/option[@selected]")[0].text)) / 60.0,
+                "duration": (float(safe_xpath(n, "td[8]/select[1]/option[@selected]", "0.0")) * 60.0 +
+                             float(safe_xpath(n, "td[8]/select[2]/option[@selected]", "0.0"))) / 60.0,
             })
